x86: Rename pcat_ to i8254 and i8259 accordingly

Rename pcat_timer.c to i8254.c and pcat_interrupts.c to i8259.c,
to match their header file names (i8254.h and i8259.h).

Signed-off-by: Bin Meng <bmeng.cn@gmail.com>
Acked-by: Simon Glass <sjg@chromium.org>
diff --git a/arch/x86/cpu/interrupts.c b/arch/x86/cpu/interrupts.c
index addd26e..b00ddc0 100644
--- a/arch/x86/cpu/interrupts.c
+++ b/arch/x86/cpu/interrupts.c
@@ -252,7 +252,7 @@
 	/* Just in case... */
 	disable_interrupts();
 
-#ifdef CONFIG_SYS_PCAT_INTERRUPTS
+#ifdef CONFIG_I8259_PIC
 	/* Initialize the master/slave i8259 pic */
 	i8259_init();
 #endif
diff --git a/arch/x86/include/asm/u-boot-x86.h b/arch/x86/include/asm/u-boot-x86.h
index 1c459d5..dbf8e95 100644
--- a/arch/x86/include/asm/u-boot-x86.h
+++ b/arch/x86/include/asm/u-boot-x86.h
@@ -29,7 +29,7 @@
 int register_timer_isr (timer_fnc_t *isr_func);
 unsigned long get_tbclk_mhz(void);
 void timer_set_base(uint64_t base);
-int pcat_timer_init(void);
+int i8254_init(void);
 
 /* cpu/.../interrupts.c */
 int cpu_init_interrupts(void);
diff --git a/arch/x86/lib/Makefile b/arch/x86/lib/Makefile
index 2f82a21..d676e2c 100644
--- a/arch/x86/lib/Makefile
+++ b/arch/x86/lib/Makefile
@@ -19,8 +19,8 @@
 obj-y	+= mpspec.o
 obj-$(CONFIG_ENABLE_MRC_CACHE) += mrccache.o
 obj-y += cmd_mtrr.o
-obj-$(CONFIG_SYS_PCAT_INTERRUPTS) += pcat_interrupts.o
-obj-$(CONFIG_SYS_PCAT_TIMER) += pcat_timer.o
+obj-$(CONFIG_I8259_PIC) += i8259.o
+obj-$(CONFIG_I8254_TIMER) += i8254.o
 ifndef CONFIG_DM_PCI
 obj-$(CONFIG_PCI) += pci_type1.o
 endif
diff --git a/arch/x86/lib/pcat_timer.c b/arch/x86/lib/i8254.c
similarity index 96%
rename from arch/x86/lib/pcat_timer.c
rename to arch/x86/lib/i8254.c
index 347cdda..46a4245 100644
--- a/arch/x86/lib/pcat_timer.c
+++ b/arch/x86/lib/i8254.c
@@ -12,7 +12,7 @@
 #define TIMER1_VALUE	18	/* 15.6us */
 #define TIMER2_VALUE	0x0a8e	/* 440Hz */
 
-int pcat_timer_init(void)
+int i8254_init(void)
 {
 	/*
 	 * Initialize counter 1, used to refresh request signal.
diff --git a/arch/x86/lib/pcat_interrupts.c b/arch/x86/lib/i8259.c
similarity index 100%
rename from arch/x86/lib/pcat_interrupts.c
rename to arch/x86/lib/i8259.c
diff --git a/arch/x86/lib/tsc_timer.c b/arch/x86/lib/tsc_timer.c
index 0df1af2..e02b918 100644
--- a/arch/x86/lib/tsc_timer.c
+++ b/arch/x86/lib/tsc_timer.c
@@ -368,9 +368,9 @@
 
 int timer_init(void)
 {
-#ifdef CONFIG_SYS_PCAT_TIMER
-	/* Set up the PCAT timer if required */
-	pcat_timer_init();
+#ifdef CONFIG_I8254_TIMER
+	/* Set up the i8254 timer if required */
+	i8254_init();
 #endif
 
 	return 0;